* Yan Bai & Will Masters, Tufts University

* Stata code for Cost of Diet Diversity  metrics
* "Measuring the Affordability of Nutritious Diets in Africa: Price Indexes for Diet Diversity and the Cost of Nutrient Adequacy"

* This code draws Figures 1, 2, A1 & A2 
* All other figures created in accompanying Excel file

* Last revised: May 24, 2018

clear
*cd "C:\Users\Ian's laptop\Google Drive\IANDA\Publications\CoDD+CoNA\Revision files\Charts and tables"
cd "C:\Users\William Masters\Box Sync\CANDASA (Shared Files)\Outputs\AJAE submission\Charts-tables"

*GHANA
* Figure 1: Cost of diet diversity in Ghana (least-cost foods to meet MDD-W)
clear
use GhanaFoodPrices_NatAvgForCoDD.dta, clear
* Keep data starting march 2009, for sufficient diversity to calculate CoDD
keep if date>=590
* For main results, use price per kcal only
gen price = ene_price_m_usd
lab var price "National average price per 1000 kcal (10 regions, >100 markets each week)"
* Identify and keep the cheapest food within each food group (by 1,000kcal)
bysort date foodgroup: egen r_withingroups=rank(price)
keep if r_withingroups==1
* Identify the 5th cheapest group to compute CoDD1
bysort date: egen r_group=rank(price) 
gen CoDD1 = price if r_group==5
* Average of cheapest food in all groups to compute CoDD2)
egen CoDD2 = mean(price), by (date)
label var CoDD1 "CoDD1 (Price of least-cost food in 5th food group, USD per 1000 kcal)" 
label var CoDD2 "CoDD2 (Avg price of least-cost foods in all groups, USD per 1000 kcal)" 
drop r* USDA_name uni_price_m_usd ene_price_m_usd
save GhanaCoDD_ResultsOnly.dta, replace

*Draw the graph: colors & symbols below are OK when printed in grayscale, must redraw CoDD2 at the end for it to be visible
#delimit;
graph twoway 
(line CoDD1 date, sort yscale(log) fcolor(none) clcolor(red) clwidth(vthick))
(line CoDD2 date, sort fcolor(none) clcolor(red) clpattern(dash) clwidth(thick))
(scatter price date if food==19, msymbol(t) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==3, msymbol(t) msize(medium) mcolor(black) mlwidth(medthick))
(scatter price date if food==7, msymbol(T) msize(large) mcolor(black) mlwidth(medthick))
(scatter price date if food==31, msymbol(o) msize(medium) mcolor(maroon) mlwidth(medthick))
(scatter price date if food==14, msymbol(s) msize(small) mcolor(maroon) mlwidth(medthick))
(scatter price date if food==20, msymbol(t) msize(small) mcolor(orange) mlwidth(medthick))
(scatter price date if food==2, msymbol(s) msize(small) mcolor(gold) mlwidth(thick))
(scatter price date if food==22, msymbol(d) msize(small) mcolor(orange) mlwidth(thick))
(scatter price date if food==28, msymbol(sh) msize(small) mcolor(dkgreen) mlwidth(medium))
(scatter price date if food==29, msymbol(sh) msize(small) mcolor(blue) mlwidth(medthick))
(scatter price date if food==9, msymbol(oh) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==11, msymbol(+) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==17, msymbol(X) msize(medium) mcolor(gray) mlwidth(medthick))
(line CoDD2 date, sort fcolor(none) clcolor(red) clpattern(dash) clwidth(thick)),
title("Cost of diet diversity in Ghana, March 2009 - December 2014", size(medium))  
subtitle(" ") 
xtitle("Year/Month", size(small)) xlabel(#12, labsize(small)) xsize(8) 
ytitle("Cost per 1,000 kcal in 2011 intl $ (log scale)" " ", size(small)) 
yscale(r(.1 12)) 
ylabel(0.2 1 3 10, labsize(small) grid glcolor(gs11) glpattern(shortdash)) 
ysize(5) 
legend(col(5) order(1 "CoDD1 index" 2 "CoDD2 index" 3 "Maize" 4 "Cassava (dried)" 5 "Cassava (fresh)" 6 "Soybeans" 7 "Groundnuts" 
8 "Mangoes" 9 "Banana" 10 "Oranges" 11 "Tilapia (dried)" 12 "Herrings (smoked)" 13 "Eggs" 14 "Eggplant (garden eggs)" 
15 "Onions (large)") size(vsmall))
note(" " "Note: Foods shown are the least-cost item in their food group that month, as defined by the Minimum Dietary Diversity for Women (MDD-W) indicator."
     "       Items are ranked in cost per unit of dietary energy. CoDD1 is the cost of reaching the 5th group, and CoDD2 is the cost of including all groups." 
	 "       Groups in ascending order of usual cost are starchy staples (maize & cassava), pulses (soybeans), nuts/seeds (groundnuts), vitamin-A rich fruits"
	 "       and vegetables (mangoes), other fruit (banana & oranges), meat and fish (tilapia & herring), eggs, and other vegetables (eggplant & onion)."
	 , size(vsmall)) ;
#delimit cr
graph save Fig1_GhCoDD.gph, replace

*TANZANIA
* Figure 2: Cost of diet diversity in Tanzania (least-cost foods to meet MDD-W) 
clear
use TanzaniaFoodPrices_NatAvgForCoDD.dta, clear
* Drop 2010 observations due to limited observations
drop if year==2010
* For main results, use price per kcal only
gen price = ene_price_usd
lab var price "National average price in constant USD per 1000 kcal (21 regions)"
* Identify and keep the cheapest food within each food group (by 1,000kcal)
bysort date foodgroup: egen r_withingroups=rank(price)
keep if r_withingroups==1
* Identify the 5th cheapest group to compute CoDD1
bysort date: egen r_group=rank(price) 
gen CoDD1 = price if r_group==5
* Average of cheapest food in all groups to compute CoDD2)
egen CoDD2 = mean(price), by (date)
label var CoDD1 "CoDD1 (Price of least-cost food in 5th food group, USD per 1000 kcal)" 
label var CoDD2 "CoDD2 (Avg price of least-cost foods in all groups, USD per 1000 kcal)" 
drop r* uni_price_usd ene_price_usd uni_price_lcu ene_price_lcu unitprice
save TanzaniaCoDD_ResultsOnly.dta, replace

*Draw the graph: colors & symbols below are OK when printed in grayscale, must redraw CoDD2 at the end for it to be visible
#delimit;
graph twoway 
(line CoDD1 date, sort yscale(log) fcolor(none) clcolor(red) clwidth(vthick))
(line CoDD2 date, sort fcolor(none) clcolor(red) clpattern(dash) clwidth(thick))
(scatter price date if food==71, msymbol(t) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==4, msymbol(o) msize(medium) mcolor(maroon) mlwidth(medthick))
(scatter price date if food==47, msymbol(s) msize(small) mcolor(maroon) mlwidth(medthick))
(scatter price date if food==7, msymbol(Dh) msize(small) mcolor(dkorange) mlwidth(medium))
(scatter price date if food==2, msymbol(Th) msize(medium) mcolor(dkgreen) mlwidth(medthick))
(scatter price date if food==13, msymbol(+) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==28, msymbol(Dh) msize(medium) mcolor(lavender) mlwidth(medium))
(scatter price date if food==43, msymbol(t) msize(small) mcolor(orange) mlwidth(medthick))
(scatter price date if food==51, msymbol(Th) msize(medium) mcolor(orange) mlwidth(medthick))
(scatter price date if food==45, msymbol(X) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==48, msymbol(oh) msize(medium) mcolor(gray) mlwidth(medthick))
(line CoDD2 date, sort fcolor(none) clcolor(red) clpattern(dash) clwidth(thick)),
title("Cost of diet diversity in Tanzania, January 2011 - December 2015", size(medium))  
subtitle(" ") 
xtitle("Year/Month", size(small)) xlabel(#12, labsize(small)) xsize(8) 
ytitle("Cost per 1,000 kcal in 2011 intl $ (log scale)" " ", size(small))  
yscale(r(.1 12)) 
ylabel(0.2 1 3 10, labsize(small) grid glcolor(gs11) glpattern(shortdash)) 
ysize(5) 
legend(col(5) order(1 "CoDD1 index" 2 "CoDD2 index" 3 "Maize (white)" 4 "Soybeans" 5 "Groundnuts" 6 "Beef" 7 "Avocado" 
8 "Cabbages" 9 "Milk" 10 "Mangoes" 11 "Papaya" 12 "Amaranth leaves" 13 "Eggs") size(vsmall))
note(" " "Note: Foods shown are the least-cost item in their food group that month, as defined by the Minimum Dietary Diversity for Women (MDD-W) indicator."
     "       Items are ranked in cost per unit of dietary energy. CoDD1 is the cost of reaching the 5th group, and CoDD2 is the cost of including all groups." 
	 "       Groups in ascending order of usual cost are a starchy staple (maize), pulses (soybeans), nuts/seeds (groundnuts), meat or fish (beef for stew),"
	 "       other fruit (avocado), other vegetable (cabbage), dairy (milk), vit A-rich fruit (mangoes or papaya), green leafy veg (amaranth), and eggs."
	 , size(vsmall)) ;
;
#delimit cr
graph save Fig2_TzCoDD.gph, replace

*FOR ANNEX: SAME CHARTS, PER KILOGRAM
*Figure A1: Cost of diet diversity in Ghana (least-cost foods to meet MDD-W, per kg)
clear
use GhanaFoodPrices_NatAvgForCoDD.dta, clear
* Keep data starting march 2009, for sufficient diversity to calculate CoDD
keep if date>=590
* For annex, use price per kg only
gen price = uni_price_m_usd
lab var price "National average price in constant USD per kilogram (10 regions)"
* Identify and keep the cheapest food within each food group 
bysort date foodgroup: egen r_withingroups=rank(price)
keep if r_withingroups==1
* Identify the 5th cheapest group to compute CoDD1
bysort date: egen r_group=rank(price) 
gen CoDD1 = price if r_group==5
* Average of cheapest food in all groups to compute CoDD2)
egen CoDD2 = mean(price), by (date)
label var CoDD1 "CoDD1 (Price of least-cost food in 5th food group, USD per kg)" 
label var CoDD2 "CoDD2 (Avg price of least-cost foods in all groups, USD per kg)" 
drop r* USDA_name uni_price_m_usd ene_price_m_usd
save GhanaCoDD_PerKgResultsOnly.dta, replace

*Draw the graph: colors & symbols below are OK when printed in grayscale, must redraw CoDD2 at the end for it to be visible
/*FOODS IN THIS CHART ARE: 
   | food                   food_name   foodgr~p                                  foodgroup_name |
   |---------------------------------------------------------------------------------------------|
   |    3                     CASSAVA          1   Grains, white roots and tubers, and plantains |
   |   19                       MAIZE          1   Grains, white roots and tubers, and plantains |
   |   31                  SOYA BEANS          2                                          Pulses |
   |   14                   GROUNDNUT          3                                  Nuts and seeds |
   |   28   SALTED DRIED TILAPIA FISH          5                          Meat, poultry and fish |
   |   29             SMOKED HERRINGS          5                          Meat, poultry and fish |
   |    9                        EGGS          6                                            Eggs |
   |   20                     MANGOES          8            Vitamin A-rich vegetables and fruits |
   |   11                 GARDEN EGGS          9                                Other vegetables |
   |   17                LARGE ONIONS          9                                Other vegetables |
   |   32                    TOMATOES          9                                Other vegetables |
   |   22                     ORANGES         10                                    Other fruits |
   |    2                      BANANA         10                                    Other fruits |
   |   26                   PINEAPPLE         10                                    Other fruits |
*/

#delimit;
graph twoway 
(line CoDD1 date, sort yscale(log) fcolor(none) clcolor(red) clwidth(vthick))
(line CoDD2 date, sort fcolor(none) clcolor(red) clpattern(dash) clwidth(thick))
(scatter price date if food==19, msymbol(t) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==3, msymbol(t) msize(medium) mcolor(black) mlwidth(medthick))
(scatter price date if food==20, msymbol(t) msize(small) mcolor(orange) mlwidth(medthick))
(scatter price date if food==31, msymbol(o) msize(medium) mcolor(maroon) mlwidth(medthick))
(scatter price date if food==22, msymbol(d) msize(small) mcolor(orange) mlwidth(thick))
(scatter price date if food==2, msymbol(s) msize(small) mcolor(gold) mlwidth(thick))
(scatter price date if food==26, msymbol(Th) msize(medium) mcolor(orange) mlwidth(medium))
(scatter price date if food==11, msymbol(+) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==17, msymbol(X) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==32, msymbol(Th) msize(medium) mcolor(maroon) mlwidth(medthick))
(scatter price date if food==28, msymbol(sh) msize(small) mcolor(dkgreen) mlwidth(medium))
(scatter price date if food==29, msymbol(sh) msize(small) mcolor(blue) mlwidth(medthick))
(scatter price date if food==14, msymbol(s) msize(small) mcolor(maroon) mlwidth(medthick))
(scatter price date if food==9, msymbol(oh) msize(medium) mcolor(gray) mlwidth(medthick))
(line CoDD2 date, sort fcolor(none) clcolor(red) clpattern(dash) clwidth(thick)),
title("Cost of diet diversity in Ghana per unit of weight (kg), Mar. 2009 - Dec. 2014", size(medium))  
subtitle(" ") 
xtitle("Year/Month", size(small)) xlabel(#12, labsize(small)) xsize(8) 
ytitle("Cost per kilogram in 2011 intl $ (log scale)" " ", size(small)) 
yscale(r(.1 12)) 
ylabel(0.2 1 3 10, labsize(small) grid glcolor(gs11) glpattern(shortdash)) 
ysize(5) 
legend(col(5) order(1 "CoDD1" 2 "CoDD2" 3 "Maize" 4 "Cassava (dried)" 5 "Mangoes" 6 "Soybeans" 7 "Oranges"  
                    8 "Bananas" 9 "Pineapples" 10 "Eggplant (garden eggs)" 11 "Onions (large)" 12 "Tomatoes (red)" 
					13 "Tilapia (dried)" 14 "Herring (smoked)" 15 "Groundnuts" 16 "Eggs") size(vsmall))
note(" " "Note: Foods shown are the least-cost item in their food group that month, as defined by the Minimum Dietary Diversity for Women (MDD-W) indicator."
     "       Items are ranked in cost per kilogram. CoDD1 is the cost of reaching the 5th group, and CoDD2 is the cost of including all groups." 
	 "       Groups in ascending order of usual cost are starchy staples (cassava & maize), pulses (soybeans), vitamin-A rich fruits and vegetables (mangoes),"
	 "       other fruit (oranges, banana and pineappples), other veg(eggplant, onion, tomatoes), meat/fish (tilapia & herring), nuts/seeds (groundnuts), eggs."
	 , size(vsmall)) ;
#delimit cr
graph save FigA1_GhCoDD.gph, replace

* Figure A2: Cost of diet diversity in TANZANIA (least-cost foods to meet MDD-W, per kg)
clear
use TanzaniaFoodPrices_NatAvgForCoDD.dta, clear
* Drop 2010 observations due to limited observations
drop if year==2010
* For annex, use price per kg only
gen price = uni_price_usd
lab var price "National average price in constant USD per kilogram (10 regions)"
* Identify and keep the cheapest food within each food group
bysort date foodgroup: egen r_withingroups=rank(price)
keep if r_withingroups==1
* Identify the 5th cheapest group to compute CoDD1
bysort date: egen r_group=rank(price) 
gen CoDD1 = price if r_group==5
* Average of cheapest food in all groups to compute CoDD2)
egen CoDD2 = mean(price), by (date)
label var CoDD1 "CoDD1 (Price of least-cost food in 5th food group, USD per kg)" 
label var CoDD2 "CoDD2 (Avg price of least-cost foods in all groups, USD per kg)" 
drop r* uni_* ene_* othername unitprice  
save TanzaniaCoDD_PerKgResultsOnly.dta, replace

*Draw the graph: colors & symbols below are OK when printed in grayscale, must redraw CoDD2 at the end for it to be visible
/*FOODS IN THIS CHART ARE: 
 |                        foodname   food   foodgr~p                                  foodgroup_name |
 |---------------------------------------------------------------------------------------------------|
 |              White Maize grains     71          1   Grains, white roots and tubers, and plantains |
 |                   Red dry beans     58          2                                          Pulses |
 | Natural Groundnuts (Un roasted)     47          3                                  Nuts and seeds |
 |                  Fresh cow milk     28          4                                           Dairy |
 |          Dried sardines (dagaa)     26          5                          Meat, poultry and fish |
 |                 One Egg  Layers     48          6                                            Eggs |
 |                         Mchicha     45          7                     Dark green leafy vegetables |
 |                         Mangoes     43          8            Vitamin A-rich fruits and vegetables |
 |                        Cabbages     13          9                                Other vegetables |
 |                         Oranges     50         10                                    Other fruits |
 |                   Cassava fresh     16          1   Grains, white roots and tubers, and plantains |
 |                 Papaya - Pawpaw     51          8            Vitamin A-rich fruits and vegetables |
 |                         Carrots     14          8            Vitamin A-rich vegetables and fruits |
*/
#delimit;
graph twoway 
(line CoDD1 date, sort yscale(log) fcolor(none) clcolor(red) clwidth(vthick))
(line CoDD2 date, sort fcolor(none) clcolor(red) clpattern(dash) clwidth(thick))
(scatter price date if food==71, msymbol(t) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==16, msymbol(t) msize(medium) mcolor(black) mlwidth(medthick))
(scatter price date if food==13, msymbol(+) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==45, msymbol(X) msize(medium) mcolor(gray) mlwidth(medthick))
(scatter price date if food==28, msymbol(Dh) msize(medium) mcolor(lavender) mlwidth(medium))
(scatter price date if food==43, msymbol(t) msize(small) mcolor(orange) mlwidth(medthick))
(scatter price date if food==50, msymbol(d) msize(small) mcolor(orange) mlwidth(thick))
(scatter price date if food==51, msymbol(Th) msize(medium) mcolor(orange) mlwidth(medthick))
(scatter price date if food==58, msymbol(T) msize(small) mcolor(maroon) mlwidth(medthick))
(scatter price date if food==47, msymbol(s) msize(small) mcolor(maroon) mlwidth(medthick))
(scatter price date if food==26, msymbol(d) msize(small) mcolor(dkorange) mlwidth(thick))
(scatter price date if food==48, msymbol(oh) msize(medium) mcolor(gray) mlwidth(medthick))
(line CoDD2 date, sort fcolor(none) clcolor(red) clpattern(dash) clwidth(medthick)),
title("Cost of diet diversity in Tanzania per unit of weight (kg), Jan. 2011 - Dec. 2015", size(medium))  
subtitle(" ") 
xtitle("Year/Month", size(small)) xlabel(#12, labsize(small)) xsize(8) 
ytitle("Cost per kilogram in 2011 intl $ (log scale)" " ", size(small)) 
yscale(r(.1 12)) 
ylabel(0.2 1 3 10, labsize(small) grid glcolor(gs11) glpattern(shortdash)) 
ysize(5)
legend(col(5) order(1 "CoDD1" 2 "CoDD2" 3 "Maize (white)" 4 "Cassava" 5 "Cabbages" 6 "Amaranth leaves"  7 "Milk" 8 "Mangoes" 
	9 "Oranges" 10 "Papaya"  11 "Beans (red dry)" 12 "Groundnuts" 13 "Sardines (dagaa)" 14 "Eggs") size(vsmall))
note(" " "Note: Foods shown are the least-cost item in their food group that month, as defined by the Minimum Dietary Diversity for Women (MDD-W) indicator."
     "       Items are ranked in cost per kilogram. CoDD1 is the cost of reaching the 5th group, and CoDD2 is the cost of including all groups." 
	 "       Groups in ascending order of usual cost are starchy staples (cassava & maize), other veg. (cabbage), dark green leafy veg. (amaranth leaves),"
	 "       milk, vitamin-A rich fruits and vegetables (mangoes, papaya), other fruit (oranges), pulses (beans),  nuts/seeds (groundnuts), meat/fish (sardines), eggs."
	 , size(vsmall)) ;
#delimit cr
graph save FigA2_TzCoDD.gph, replace
